@@ -112,10 +112,11 @@ extension_map = {
     "GZ": "archives",
 }
 
-def load_file_contents(file_path, chunk_size=250):
+def load_file_contents(file_path, chunk_size=None):
     file_ext = os.path.splitext(file_path)[1].upper().lstrip('.')
     full_content = ""
-    
+    if not isinstance(chunk_size, int):
+        chunk_size=250
     try:
         if file_ext == 'PDF':
             full_content = load_pdf(file_path)
@@ -131,7 +132,7 @@ def load_file_contents(file_path, chunk_size=250):
         elif file_ext in ['XLS', 'XLSX']:
             df = load_excel(file_path)
             full_content = df.to_string()
-        elif file_ext in ['TXT', 'MD']:
+        elif file_ext in ['TXT', 'MD', 'PY', 'JSX', 'TSX', 'TS', 'JS', 'JSON', 'SQL', 'NPC', 'JINX', 'LINE', 'YAML']:
             full_content = load_txt(file_path)
         elif file_ext == 'JSON':
             data = load_json(file_path)
