@@ -1,4 +1,4 @@
-# search.py
+
 
 import requests
 import os
@@ -21,6 +21,25 @@ except:
     pass
 
 
+
+
+
+def search_exa(query:str, 
+               api_key:str = None, 
+               top_k = 5,
+               **kwargs):
+    from exa_py import Exa
+    if api_key is None:
+        api_key = os.environ.get('EXA_API_KEY') 
+    exa = Exa(api_key)
+
+    results = exa.search_and_contents(
+        query, 
+        text=True   
+    )
+    return results.results[0:top_k]
+
+
 def search_perplexity(
     query: str,
     api_key: str = None,
@@ -30,8 +49,13 @@ def search_perplexity(
     top_p: float = 0.9,
 ):
     if api_key is None:
-        api_key = os.environ["PERPLEXITY_API_KEY"]
-    # print("api_key", api_key)
+        api_key = os.environ.get("PERPLEXITY_API_KEY")
+        if api_key is None: 
+            raise 
+        
+    print(api_key[0:5])
+        
+    
     url = "https://api.perplexity.ai/chat/completions"
     payload = {
         "model": "sonar",
@@ -52,13 +76,17 @@ def search_perplexity(
         "response_format": None,
     }
 
-    # Headers for the request, including the Authorization bearer token
-    headers = {"Authorization": f"Bearer {api_key}", "Content-Type": "application/json"}
+    
+    headers = {"Authorization": f"Bearer {api_key}", 
+               "Content-Type": "application/json"}
 
-    # Make the POST request to the API
-    response = requests.post(url, json=payload, headers=headers)
+    
+    response = requests.post(url,
+                             json=payload,
+                             headers=headers)
+    print('response')
     response = json.loads(response.text)
-    #print(response)
+    print(response)
     return [response["choices"][0]["message"]["content"], response["citations"]]
 
 
@@ -88,7 +116,7 @@ def search_web(
 
     if provider == "perplexity":
         search_result = search_perplexity(query, api_key=api_key, **perplexity_kwargs)
-        # print(search_result, type(search_result))
+        
         return search_result
 
     if provider == "duckduckgo":
@@ -108,30 +136,32 @@ def search_web(
             print("DuckDuckGo search failed: ", e)
             urls = []
             results = []
+    elif provider =='exa':
+        return search_exa(query, api_key=api_key, )
 
-    elif provider =='google':  # google
+    elif provider =='google':  
         urls = list(search(query, num_results=num_results))
-        # google shit doesnt seem to be working anymore, apparently a lbock they made on browsers without js?
-        #print("urls", urls)
-        #print(provider)
+        
+        
+        
         for url in urls:
             try:
-                # Fetch the webpage content
+                
                 headers = {
                     "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36"
                 }
                 response = requests.get(url, headers=headers, timeout=5)
                 response.raise_for_status()
 
-                # Parse with BeautifulSoup
+                
                 soup = BeautifulSoup(response.text, "html.parser")
 
-                # Get title and content
+                
                 title = soup.title.string if soup.title else url
 
-                # Extract text content and clean it up
+                
                 content = " ".join([p.get_text() for p in soup.find_all("p")])
-                content = " ".join(content.split())  # Clean up whitespace
+                content = " ".join(content.split())  
 
                 results.append(
                     {
@@ -147,8 +177,8 @@ def search_web(
                 print(f"Error fetching {url}: {str(e)}")
                 continue
 
-    # except Exception as e:
-    #    print(f"Search error: {str(e)}")
+    
+    
     content_str = "\n".join(
         [r["content"] + "\n Citation: " + r["link"] + "\n\n\n" for r in results]
     )
